@@ -8,32 +8,24 @@ as_integer_tensor <- function(x, dtype = tf$int64) {
   else if (is.null(x))
     x
   else if (is_tensor(x))
-    tensor_value(tf$cast(x, dtype = dtype))
+    tf$cast(x, dtype = dtype)
   else
-    tensor_value(tf$constant(as.integer(x), dtype = dtype))
+    tf$constant(as.integer(x), dtype = dtype)
 }
 
 as_tensor_shapes <- function(x) {
   if (is.list(x))
     tuple(lapply(x, as_tensor_shapes))
   else if (is_tensor(x))
-    tensor_value(tf$cast(x, dtype = tf$int64))
+    tf$cast(x, dtype = tf$int64)
   else if (inherits(x, "python.builtin.object"))
     x
   else if (is.null(x))
-    tensor_value(tf$constant(-1L, dtype = tf$int64))
+    tf$constant(-1L, dtype = tf$int64)
   else
-    tensor_value(tf$constant(as.integer(x), dtype = tf$int64))
+    tf$constant(as.integer(x), dtype = tf$int64)
 }
 
-tensor_value <- function(x) {
-  if (is_eager_tensor(x))
-    x$numpy()
-  else
-    x
-}
-
-
 with_session <- function(f, session = NULL) {
   if (is.null(session))
     session <- tf$get_default_session()
@@ -67,7 +59,8 @@ column_names <- function(dataset) {
 }
 
 is_dataset <- function(x) {
-  inherits(x, "tensorflow.python.data.ops.dataset_ops.Dataset")
+  inherits(x, "tensorflow.python.data.ops.dataset_ops.Dataset") ||
+  inherits(x, "tensorflow.python.data.ops.dataset_ops.DatasetV2")
 }
 
 is_tensor <- function(x) {
