@@ -2,6 +2,8 @@ context("dataset-prepare")
 
 source("utils.R")
 
+require(keras)
+
 test_succeeds("dataset_prepare yields list of x and y tensors", {
   batch <- mtcars_dataset() %>%
     dataset_prepare(x = c(mpg, disp), y = cyl) %>%
@@ -17,8 +19,8 @@ test_succeeds("dataset_prepare accepts formula syntax", {
 })
 
 test_succeeds("dataset_prepare can fuse dataset_batch", {
-  batch <- mtcars_dataset() %>%
-    dataset_prepare(cyl ~ mpg + disp, batch_size = 16) %>%
+  batch <- mtcars_dataset_nobatch() %>%
+    dataset_prepare(cyl ~ mpg + disp, batch_size = 16L) %>%
     next_batch()
   expect_length(setdiff(names(batch), c("x", "y")), 0)
 })
@@ -46,8 +48,6 @@ test_succeeds("dataset_prepare can return an unnamed list", {
 
 test_succeeds("dataset_prepare can provide keras input tensors", {
 
-  require(keras)
-
   # create dataset
   dataset <- csv_dataset("data/iris.csv") %>%
     dataset_map(function(record) {
@@ -62,23 +62,46 @@ test_succeeds("dataset_prepare can provide keras input tensors", {
   # stream batches from dataset
   train_batch <- next_batch(dataset)
 
-  # create model
-  input <- layer_input(tensor = train_batch$x, shape = c(4))
-  predictions <- input %>%
-    layer_dense(units = 10, activation = "relu") %>%
-    layer_dense(units = 20, activation = "relu") %>%
-    layer_dense(units = 3, activation = "softmax")
-  model <- keras_model(input, predictions)
-  model %>% compile(
-    loss = 'categorical_crossentropy',
-    optimizer = optimizer_rmsprop(),
-    metrics = c('accuracy'),
-    target_tensors = train_batch$y
-  )
+  if (tensorflow::tf_version() >= "2.0") {
+
+    # You should not pass an EagerTensor to `Input`.
+    # For example, instead of creating an InputLayer, you should instantiate your model and directly
+    # call it on your input.
+    model <- tf$keras$Sequential(
+      list(tf$keras$layers$Dense(10L, tf$nn$relu),
+           tf$keras$layers$Dense(10L, tf$nn$relu),
+           tf$keras$layers$Dense(3L, tf$nn$softmax))
+    )
+
+    model$compile(loss = "categorical_crossentropy",
+                  optimizer = "adam",
+                  metrics = list("accuracy"))
+
+    model$fit(train_batch$x,
+              train_batch$y,
+              epochs = 5L)
+
+  } else {
+
+    input <- layer_input(tensor = train_batch$x, shape = c(4))
+    predictions <- input %>%
+      layer_dense(units = 10, activation = "relu") %>%
+      layer_dense(units = 20, activation = "relu") %>%
+      layer_dense(units = 3, activation = "softmax")
+    model <- keras_model(input, predictions)
+
+    model %>% compile(
+      loss = 'categorical_crossentropy',
+      optimizer = optimizer_rmsprop(),
+      metrics = c('accuracy'),
+      target_tensors = train_batch$y
+    )
+
+    # see above
+    model %>% fit(
+      steps_per_epoch = 15L,
+      epochs = 5
+    )
+  }
 
-  # fit with the generator
-  model %>% fit(
-    steps_per_epoch = 15L,
-    epochs = 5
-  )
 })
