@@ -12,6 +12,16 @@ skip_if_no_tensorflow <- function(required_version = NULL) {
   }
 }
 
+skip_if_eager <- function(message) {
+  if (tf$executing_eagerly())
+    skip(message)
+}
+
+skip_if_v2 <- function(message) {
+  if (tensorflow::tf_version() >= "2.0")
+    skip(message)
+}
+
 test_succeeds <- function(desc, expr, required_version = NULL) {
   test_that(desc, {
     skip_if_no_tensorflow(required_version)
@@ -30,6 +40,9 @@ mtcars_dataset <- function() {
     dataset_batch(10)
 }
 
-
+mtcars_dataset_nobatch <- function() {
+  csv_dataset("data/mtcars.csv") %>%
+    dataset_shuffle(50)
+}
 
 
